/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * For demonstration purpose only.
 * MicroEJ Corp. PROPRIETARY. Use is subject to license terms.
 */
package com.microej.demo.thermorest.cloud;

import java.util.Observable;

import com.microej.demo.thermorest.HeadlessThermostat;
import com.microej.demo.thermorest.model.ThermostatListener;

/**
 * A cloud connector that can be added to a {@link HeadlessThermostat}.
 */
public abstract class CloudConnector extends Observable implements ThermostatListener {

	/**
	 * Gets the listener name, can be <code>null</code>.
	 *
	 * @return the listener name, can be <code>null</code>.
	 */
	public abstract String getName();

	/**
	 * Checks whether the listener is connected.
	 *
	 * @return <code>true</code> if the connector is connected.
	 */
	public abstract boolean isConnected();

	/**
	 * Starts the connector behaviour.
	 */
	public abstract void start();

	/**
	 * Stops the connector behaviour.
	 */
	public abstract void stop();

	/**
	 * Checks whether the connector is in error state.
	 *
	 * @return <code>true</code> if the connector is in error.
	 */
	public boolean isError() {
		return false;
	}

}
