/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.profiler;

import java.util.logging.Logger;

import com.microej.profiling.internal.Strings;

/**
 * Profile the heap memory usage.
 */
public class HeapProfiler extends MemoryProfiler {
	/**
	 * Sets the memory offset.
	 */
	public static volatile int OFFSET = 0;

	private final Runtime runtime;

	/**
	 * Instantiates a {@link MemoryProfiler}.
	 */
	public HeapProfiler() {
		this.runtime = Runtime.getRuntime();
	}

	/**
	 * Prints the used heap memory.
	 *
	 * @param printTotal
	 *            <code>true</code> if the total memory should be printed.
	 */
	public static void printUsedMemory(boolean printTotal) {
		Runtime runtime = getRuntime();
		printMemory(getLogger(), runtime.totalMemory(), runtime.freeMemory(), true, printTotal);
	}

	/**
	 * Prints the free heap memory.
	 *
	 * @param printTotal
	 *            <code>true</code> if the total memory should be printed.
	 */
	public static void printFreeMemory(boolean printTotal) {
		Runtime runtime = getRuntime();
		printMemory(getLogger(), runtime.totalMemory(), runtime.freeMemory(), false, printTotal);
	}

	private static Logger getLogger() {
		return Logger.getLogger(HeapProfiler.class.getSimpleName());
	}

	private static Runtime getRuntime() {
		Runtime runtime = Runtime.getRuntime();
		System.gc();
		return runtime;
	}

	@Override
	public long getCurrentValue() {
		System.gc();
		return this.runtime.freeMemory() + OFFSET;
	}

	@Override
	protected long getTotal() {
		return this.runtime.totalMemory();
	}

	@Override
	protected String getType() {
		return Strings.HEAP;
	}
}
