/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.audio;

import java.io.IOException;


/**
 * Class audio player to play sound with limited functionality.
 */
public class AudioPlayer {

	/**
	 * Boolean indicating a mute state.
	 */
	public static final boolean SOUND_OFF = false;
	/**
	 * Boolean indicating sound output is ON.
	 */
	public static final boolean SOUND_ON = true;

	/**
	 * Constructs an {@link AudioPlayer} object.
	 *
	 */
	private AudioPlayer() {
		throw new RuntimeException();
	}
	/**
	 *
	 * @return The singleton instance of {@link AudioPlayer}.
	 *
	 */
	public static AudioPlayer getInstance() {
		throw new RuntimeException();
	}


	/**
	 * Load a {@link Playlist} in the {@link AudioPlayer}.
	 * Using a Playlist with an {@link AudioPlayer} is not required.
	 * You may chose not to initialize the {@link Playlist}.
	 * The next / previous will do nothing if no {@link Playlist} is initialized.
	 *
	 * @param Playlist
	 *            {@link Playlist} to load into the audio player.
	 */
	public void loadPlaylist(Playlist Playlist) {
		throw new RuntimeException();
	}

	/**
	 * Plays an {@link AudioFile}. This function will blocks for duration seconds.
	 * If a file is already playing, it will stop playing this file and the selected AudioFile.
	 *
	 * @param audioFile
	 *            {@link AudioFile} to play.
	 * @param duration
	 *            in seconds, how long will be the file be played.
	 * @throws IOException
	 *             Low level code failed or has not been initialized.
	 */
	public void play(AudioFile audioFile, int duration) throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Plays the currently selected file in the Playlist.
	 * This methods will blocks for duration seconds.
	 * If a file is already playing, it will stop playing this file and the selected AudioFile.
	 *
	 * @param duration
	 *            in seconds, how long will the file be played.
	 * @throws IOException
	 *             Low level code failed or has not been initialized.
	 */
	public void play(int duration) throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Plays the next file in the {@link Playlist}..
	 * This function will blocks for @param duration seconds.
	 * This methods does nothing if you haven't loaded a {@link Playlist}..
	 * If a file is already playing, it will stop playing this file and the selected AudioFile.
	 *
	 * @param duration
	 *            in seconds, how long will the file be played.
	 * @throws IOException
	 *             Low level code failed or has not been initialized.
	 */
	public void next(int duration) throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Plays the previous file in the {@link Playlist}.
	 * This function will blocks for duration seconds.
	 * This methods does nothing if you haven't loaded a {@link Playlist}.
	 * If a file is already playing, it will stop playing this file and the selected AudioFile.
	 *
	 * @param duration
	 *            in seconds, how long will the file be played.
	 *
	 * @throws IOException
	 *             Low level code failed or has not been initialized.
	 */
	public void previous(int duration) throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Pause the file currently playing.
	 *
	 * @throws IOException
	 *             Low level code failed or has not been initialized.
	 */
	public void pause() throws IOException {
		throw new RuntimeException();
	}

	/**
	 * Set the volume in percentage.
	 *
	 * @param volume
	 *            volume in percentage.
	 */
	public void setVolume(int volume) {
		throw new RuntimeException();
	}

	/**
	 * Get the volume value.
	 *
	 * @return current volume in percent.
	 */
	public int getVolume() {
		throw new RuntimeException();
	}

	/**
	 * Mute audio output.
	 */
	public void mute() {
		throw new RuntimeException();
	}

	/**
	 * Un-mute audio output.
	 */
	public void unmute() {
		throw new RuntimeException();
	}

	/**
	 * Getter for the current state of the audio output.
	 * Return true if the {@link AudioPlayer} is not muted. Return false otherwise.
	 *
	 * @return AudioOutputState.
	 */
	public boolean getAudioOutputState() {
		throw new RuntimeException();
	}

	/**
	 * Get the name of the currently selected file in the play list. It is not the name of the currently playing file.
	 * Return an empty string if {@link Playlist} is not initialized.
	 *
	 * @return the field name of the current {@link AudioFile} in the {@link Playlist}.
	 */
	public String getCurrentSoundTitle() {
		throw new RuntimeException();
	}

	/**
	 * Set the {@link Playlist} to the first {link @AudioFile}.
	 */
	public void restartPlaylist() {
		throw new RuntimeException();
	}

	/**
	 * Read the file selected by the index on the {@link Playlist}.
	 *
	 * @param index
	 * 			the index of the file to select in the {@link Playlist} between 0 and Playlist's size - 1
	 */
	public void setPlaylistByIndex(int index) {
		throw new RuntimeException();
	}

}
