/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.authz.acl;

import ej.basictool.map.PackedMap;

/**
 * Implementation of {@link AclDataAccess} that stores all the permissions of the enforced policy in memory.
 * <p>
 * This class is thread-safe.
 *
 * @see PackedMap
 */
public class AclInMemoryDatabase implements AclDataAccess {

	private final PackedMap<Object, PackedMap<String, AclEntry>> permissionsByResource;

	/**
	 * Constructs an empty database.
	 */
	public AclInMemoryDatabase() {
		this.permissionsByResource = new PackedMap<>();
	}

	@Override
	public synchronized void add(String user, String action, Object resource) {
		PackedMap<String, AclEntry> permissions = this.permissionsByResource.get(resource);
		if (permissions == null) {
			permissions = new PackedMap<>();
			this.permissionsByResource.put(resource, permissions);
		}

		AclEntry entry = permissions.get(user);
		if (entry == null) {
			entry = new AclEntry();
			permissions.put(user, entry);
		}

		entry.add(action);
	}

	@Override
	public synchronized AclEntry getEntry(String user, Object resource) {
		PackedMap<String, AclEntry> permissions = this.permissionsByResource.get(resource);
		if (permissions == null) {
			return null;
		}

		return new AclEntry(permissions.get(user));
	}

}
