/*
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.components.registry.util;

import ej.components.registry.BundleActivator;

/**
 * A composite activator wraps several other activators.
 * <p>
 * The state of the inner activators follows the composite activator state.
 */
public class CompositeActivator implements BundleActivator {

	private final BundleActivator[] bundles;

	/**
	 * Creates a composite activator with its list of inner activators.
	 *
	 * @param bundles
	 *            the list of inner bundles.
	 */
	public CompositeActivator(BundleActivator[] bundles) {
		this.bundles = bundles;
	}

	/**
	 * Initializes the inner activators.
	 */
	@Override
	public void initialize() {
		for (BundleActivator bundleActivator : this.bundles) {
			bundleActivator.initialize();
		}
	}

	/**
	 * Links the inner activators.
	 */
	@Override
	public void link() {
		for (BundleActivator bundleActivator : this.bundles) {
			bundleActivator.link();
		}
	}

	/**
	 * Starts the inner activators.
	 */
	@Override
	public void start() {
		for (BundleActivator bundleActivator : this.bundles) {
			bundleActivator.start();
		}
	}

	/**
	 * Stops the inner activators.
	 */
	@Override
	public void stop() {
		for (BundleActivator bundleActivator : this.bundles) {
			bundleActivator.stop();
		}
	}

}
