/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.style.Element;
import ej.style.Selector;

/**
 * An attribute value end selector selects by checking that the value of an attribute ends with a specific string.
 * <p>
 * Equivalent to <code>[attribute$=value]</code> selector in CSS. Its specificity is (0,0,1,0).
 *
 * @see Element#getAttribute(String)
 * @see SpecificityHelper
 */
public class AttributeValueEndSelector implements Selector {

	private final String attribute;
	private final String value;

	/**
	 * Creates an attribute value end selector.
	 *
	 * @param attribute
	 *            the attribute to check.
	 * @param value
	 *            the value to check.
	 */
	public AttributeValueEndSelector(String attribute, String value) {
		this.attribute = attribute;
		this.value = value;
	}

	@Override
	public boolean fit(Element element) {
		String value = element.getAttribute(this.attribute);
		return value != null && value.endsWith(this.value);
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 0, 1, 0);
	}

}
